pub enum SwitchCpuWide {
    In {
        pid: u32,
        tid: u32,
    },
    Out {
        pid: u32,
        tid: u32,
    },
}
SWITCH_CPU_WIDE records indicates a context switch when profiling in cpu-wide mode.

It provides some additional info on the process being switched that is not provided by SWITCH.

If the PERF_RECORD_MISC_SWITCH_OUT bit is set within the record header then it was a context switch away from the current process, otherwise it is a context switch into the current process.

This enum corresponds to PERF_RECORD_SWITCH_CPU_WIDE. See the manpage for more documentation.

Variants



In

Fields

pid: u32

The process ID of the process being switched into.

tid: u32

The thread IF of the thread being switched into.

A context switch into the current process.



Out

Fields

pid: u32

The process ID of the process being switched away from.

tid: u32

The thread ID of the thread being switched away from.

A context switch away from the current process.

Implementations

source

impl SwitchCpuWide

source

pub fn pid(&self) -> u32

The process ID associated with the switch.

source

pub fn tid(&self) -> u32

The thread ID associated with the switch.