Struct perf_event_data::Registers
source · pub struct Registers<'a> {
pub abi: SampleRegsAbi,
pub mask: u64,
pub regs: Cow<'a, [u64]>,
}Expand description
Describes the captured subset of registers when a sample was taken.
See the manpage for all the details.
Fields
abi: SampleRegsAbiThe ABI of the program from which the sample was taken.
mask: u64A bitmask indicating which registers were recorded.
This is configured as a part of constructing the sampler.
regs: Cow<'a, [u64]>The recorded values of the registers.
Implementations
sourceimpl<'p> Registers<'p>
impl<'p> Registers<'p>
sourcepub fn parse_user<B, E>(p: &mut Parser<B, E>) -> ParseResult<Self>where
E: Endian,
B: ParseBuf<'p>,
pub fn parse_user<B, E>(p: &mut Parser<B, E>) -> ParseResult<Self>where E: Endian, B: ParseBuf<'p>,
Parse registers using the user registers mask in the config.
sourcepub fn parse_intr<B, E>(p: &mut Parser<B, E>) -> ParseResult<Self>where
E: Endian,
B: ParseBuf<'p>,
pub fn parse_intr<B, E>(p: &mut Parser<B, E>) -> ParseResult<Self>where E: Endian, B: ParseBuf<'p>,
Parse registers using the intr registers mask in the config.